function [condPos, lim] = genRndCondPos(wireRad, outerRad)
%GENRNDCONDPOS generates random conductor positions for given wires
%
% INPUT wireRad: radius of the wires (1xnumWires)
%       outerRad: (optional) radius of the tube where all wires should be
%                   placed in
%
% OUTPUT condPos: (numWiresx2)-array with (x,y)-coordinates of wires
%           centres.
%        lim: (1x4)-array: [xmin xmax ymin ymax] area where all conductors
%           fit in

%function that will generate conductor positions
genCondPosF = @polarRand;
%number of tries to find suitable wire positions
NUMTRIES = 25000;

if (~exist('outerRad', 'var'))
    %the area that is provided for placement of the conductors is the area that
    %the conductors will occupie times this factor. -> if you get errors that
    %no suitable position could be found for a conductor, one possibility is to
    %increase this value (the other one is to increase the number of tries in
    %getRandPos and here)
    OVERRATE = 2.5;
    %we assume that the conductors should be placed in a circular area

    %get the area that is needed
    totArea = sum(pi*((wireRad).^2));
    %area of the circle in which the conductors may be placed
    neededArea = OVERRATE*totArea;
    %radius of the circle that the wires will be in
    outerRad = sqrt(neededArea/pi);
end

tf = false; %indicates if valid positions have been found
for l = 1:NUMTRIES
    [tf condPos] = genCondPosF(outerRad, wireRad);
    if (tf)
        break;
    end
end

%couldn't find valid positions
if (~tf)
    disp('tubesYZ: wires have following radii:');
    disp(wireRad);
    disp(['tubesYZ: trying to fit conductors into circle with radius ' num2str(outerRad)]);
    error('unable to find suitable wire positions');
end

%area of "image"
lim = [-outerRad outerRad -outerRad outerRad];