function [valid condPos] = polarRand(R, wireRad)
%POLARRAND generates random coordinates in a circle
%
% SYNOPSIS [valid condPos] = polarRand(R, wireRad)
%
% INPUT R: radius of circle in which positions should be found
%       wireRad: array with radii of the wires
%
% OUTPUT valid: was the algorithm successfull?
%        condPos: positions (if valid = true)
%
% Note: the positions are equally distributed in the x-y-plane

condPos = zeros(length(wireRad), 2);
r = zeros(length(wireRad));
phi = zeros(length(wireRad));

for k = 1:length(wireRad)
    %create in cartesian coordinates uniformly distributed polar coordinates
    %the maximum radius is chosen so that no wire will be outside the
    %circle

    MAXTRY = 25000;
    for numTry = 1:MAXTRY
        
        r(k) = (R-wireRad(k))*sqrt( rand() );
        phi(k) = 2*pi*rand();
        valid = true; %assume this is a valid position
    
        %check if the new position would collide with an old position
        for l = 1:k-1
            or = r(l);
            ophi = phi(l);
            %distance between the two points
            d = sqrt( r(k)*r(k) + or*or - 2*r(k)*or*cos(phi(k)-ophi) );
            if (d < wireRad(k) + wireRad(l))
                valid = false;
                break;
            end
        end
        
        if (valid)
            condPos(k, :) = [r(k)*cos(phi(k)) r(k)*sin(phi(k))];
            break;
        end
    end
    if (~valid)
        return;
    end
end
