addpath('../common');
addpath(genpath('../mtlPUL'));

%frequencies at which to evaluate the TF
f = 1e5:1e5:80e6;
nFreq = length(f);

%properties of the ground plane
gndProp.gndSigma = 3.5e7;
gndProp.gndDist = 10e-3;
gndProp.gndHeight = 1e-3;
gndProp.gndWidth = 50e-3;


%we identified three VBAT paths through the harness, you can choose one
%here or specify your own

% %Note: this path causes numerical problems if Y_TX is 0
% tx = 'C153S';
% rx = 'C251S';
% txWire = '9007C'; %'8000C'; %
% rxWire = '9007L'; %'8000B'; %
% % Y_TX = repmat( (1/50) * eye(7), [1 1 length(f)]);
% Y_TX = zeros(7, 7, length(f));

% tx = 'C347P';
% rx = 'C346P';
% txWire = '5010B';
% rxWire = '5010B';
% % Y_TX = repmat( (1/50) * eye(13), [1 1 length(f)]);
% Y_TX = zeros(13, 13, length(f));

tx = 'C310S';
rx = 'C053S';
txWire = '2053G';
rxWire = '2053DB'; %'2053DA';
% Y_TX = repmat( (1/50) * eye(22), [1 1 length(f)]);
Y_TX = zeros(22, 22, length(f));

%at a splice, all wires are connected
splY = @(nP, f) repmat(1e5*(diag(-ones(1, nP-1), -1) + diag(-ones(1, nP-1), 1) + ...
    diag([1 2*ones(1, nP-2) 1], 0)), [1 1 length(f)]);
%we assume that the connetors are open
cY = @(nP, f) zeros(nP, nP, length(f));
%RT... is a connection to the ground plane
rtY = @(nP, f) repmat(1e5*eye(nP), [1 1 length(f)]);
%jct... is a purely virtual thing introduced earlier -> no loads there
jctY = cY;
%we simply assume all resistances are 50 ohm
rY = @(nP, f) repmat((1/50)*(diag(-ones(1, nP-1), -1) + diag(-ones(1, nP-1), 1) + ...
    diag([1 2*ones(1, nP-2) 1], 0)), [1 1 length(f)]);
%the same for diodes. We cannot simulate the properties of diodes properly
%at this point.
dY = rY;

%load the input data (wires, edges, ...)
load('input/carHarness.mat');

numNodes = length(nodes);

%load admittance matrices
Y_L = cell(1, numNodes);
for k = 1:numNodes
    
    if (strncmp(nodes{k}, 'C', 1))
        Y_L{k} = cY;
    elseif (strncmp(nodes{k}, 'RT', 2))
        Y_L{k} = rtY;
    elseif (strncmp(nodes{k}, 'SPL', 3))
        Y_L{k} = splY;
    elseif (strncmp(nodes{k}, 'JCT', 3))
        Y_L{k} = jctY;
    elseif (strncmp(nodes{k}, 'R', 1))
        Y_L{k} = rY;
    elseif (strncmp(nodes{k}, 'D', 1))
        Y_L{k} = dY;
    else
        error('unknown node name');
    end
end

%compute the SISO TF
H_SISO = MTLHarnessTF(f, nodes, edges, wires, ...
    tx, rx, txWire, rxWire, Y_L, Y_TX, gndProp);
%plot it (with thicker lines and with useful markers)
printFun(f/1e6, 20*log10(abs(H_SISO)), 'auto', {'Example TF'});