function numPorts = genNumPorts(tree, tubes)
%GENNUMPORTS counts the number of ports at each junction
%
% SYNOPSIS numPorts = genNumPorts(tree, tubes)
%
% INPUT tree
%           .descr: name of the junction (used for debugging)
%       tubes
%           .(src|dst)Idx: index of (src|dst) in the tree array
%           .(src|dst)Conn: connection array at the (src|dst) of the tube
%
% OUTPUT numPorts: number of ports at every node in tree.

numPorts = zeros(1, length(tree));

for k = 1:length(tree)
    %id of the tubes that have the current junction as source
    srcIdx = ([tubes.srcIdx] == k);
    %id of the tubes that have the current junction as destination
    dstIdx = ([tubes.dstIdx] == k);
    
    %if both arrays are all zeros, the current junction isn't needed
    if ( (0 == sum(srcIdx)) && (0 == sum(dstIdx)) )
        disp(['addNumPorts: WARNING: junction ' tree(k).descr ...
            'does not appear as source or destination in any of the tubes']);
    end
    
    %get the number of unique port numbers that connect from the source
    srcPorts = unique([tubes(srcIdx).srcConn]);
    %same for the tube that has the junction as destination
    dstPorts = unique([tubes(dstIdx).dstConn]);
    
    ports = unique([srcPorts dstPorts]);
    
    numPorts(k) = numel(ports);
end


end