% R,C,L,G parameters for 3-conductor symmetric cable
% assuming homogeneous dielectric
% a la Versolatto & Tonello

function [R,C,L,G] = flat_three_outer(f)
e0 = 8.854e-12; % F / m
m0 = 4*pi*1e-7; % H / m
er = 3.5;
d = 3.4e-3; % m
rw = 0.79e-3; % m
sigmad = 1e-5; % S/m
sigmac = 5.8e7; % S/m
ns = 15;
ne = 13;
lg = m0/pi*log(2*d/rw);
lm = lg/2;
lr = (m0/pi)*log(d/rw);
L = [lg lm;lm lr];
C = inv(L)*m0*e0*er;
G = inv(L)*m0*sigmad;
rsolid = sqrt(m0*f/(4*sigmac*pi*rw^2)); % 1/(sigmac*pi*rw^2);
delta = 1/sqrt(pi*m0*f*sigmac);
rs = rw/sqrt(ns);
XR = ne*(acos((rs-delta)/rs)*rs^2-(rs-delta)*sqrt(rs^2-(rs-delta)^2))/(2*pi*rw*delta);
r = rsolid/XR;
R = [2*r r; r 2*r];