%PUL parameters for VVF (vinyl insulation vinyl sheath flat), according to:
%"An estimation method of the transfer function of inddor power-line
%channels for Japanese houses", S.Tsuzuki, T. Takamatsu, H. Nishio, and Y.
%Yamada, in Proc. Int. Symp. Power-Lines Commun., Athens, Greece, 2002, pp.
%55-59

function [R, C, L, G] = flat_two(f)

r = 0.8e-3;
d = 3.2e-3;
sigma = 5.5758e7;
mu_0 = 4*pi*(1e-7);
mu_s = 0.9999906;
mu = mu_0*mu_s;
eps_0 = 8.8542e-12;
if (f < 70e3)
    error('no eps_r for that frequency known');
elseif ( (f >= 70e3) && (f <= 5e6) )
    eps_r = -0.8802*log10(f)+8.9964;
elseif ( (f > 5e6) && (f <= 35e6) )
    eps_r = f*(-3.3333e-9)+3.1167;
else
    error('flat_two:unknownPar', 'relative permittivity unknown for this frequency');
end
eps = eps_0*eps_r;
if (f < 70e3)
    error('flat_two:unknownPar', 'no tand for this frequency known');
elseif ( (f >= 70e3) && (f <= 35e6) )
    tand = (-5.7257e-10)*f + 0.06;
else
    tand = 0.06; %this is just a guess, and not from the paper
end

R = (1/r) * sqrt((mu*f)/(pi*sigma));
L = (mu_0/pi)*acosh(d/(2*r));
C = (pi*eps)/(acosh(d/(2*r)));
G = 2*pi*f*C*tand;
