function H_LPORT = edge2NodeTF( H_Edge, Y_LNode, conn)
%EDGENODETF computes the TF from edge to node, using edge TF
%
% SYNOPSIS H = edge2NodeTF(H_Edge, Y_L, conn)
%
% INPUT H_Edge  : Transfer function for edge
%       Y_LNode : Admittance matrix at node
%       conn    : connection array at node
%
% OUTPUT H: transfer function from edge to node

numFreq = size(H_Edge, 3);
numLPorts = size(Y_LNode, 1); %number of ports at the leaf
numEWires = size(H_Edge, 1); %number of wires at the edge
notConn = setdiff(1:numLPorts, conn); %set of not-connected wires
H_LPORT = zeros(numLPorts, numEWires, numFreq);

%The following is based on the fact that the current at non-connected ports
%is zero. For more information refer to the thesis.
for k = 1:numFreq
    
    if (isinf(cond(Y_LNode(notConn, notConn, k))))
        gamma = zeros(length(notConn), length(conn));
    else
        gamma = (Y_LNode(notConn, notConn, k)) \ (-Y_LNode(notConn, conn, k));
    end
    
    H_LPORT(conn, :, k) = H_Edge(:,:, k);
    H_LPORT(notConn, :, k) = gamma*H_Edge(:,:,k);
end
