function [nodes, Y_L, edges, PUL] = edgeSplit(nodes, Y_L, edges, PUL, MAXLEN)
%EDGESPLIT splits edges to obtain edges of maximum length MAXLEN
%
% SYNOPSIS [nodes, Y_L, edges, PUL] = edgeSplit(nodes, Y_L, edges, PUL,
% MAXLEN)
%
%
if (~exist('MAXLEN', 'var'))
    MAXLEN = 1;
end

zkIdx = 0; %how many nodes we added
edgeAddIdx = length(edges) + 1; %where to add an edge
nodeAddIdx = length(nodes) + 1; %where to add a node

%note: this sucks. try to work with indices instead?
prefix = 'ZK';
while (sum(strncmp(prefix, nodes, length(prefix))) ~= 0)
    prefix = ['_' prefix];
end

for k = 1:length(edges)
    
    %we start at the source node of the edge
    currIdx = find(strcmp(edges(k).src, nodes));
    
    %in every step, we:
    % - add a node
    % - the node gets an empty admittance matrix the same size as the 
    %   current node 'currIdx'
    % - connect current node 'currIdx' to new node using a edge of length 1
    % - decrease the original edge's length by 1
    % - the new edge gets the same PUL parameters as the original edge
    % - set currIdx to the new node's idx
    % - increase both nodeAddIdx and edgeAddIdx
    while(edges(k).len > MAXLEN)
        %add extra node
        nodes{nodeAddIdx} = [prefix num2str(zkIdx)]; zkIdx = zkIdx + 1;
        Y_L{nodeAddIdx} = zeros(size(Y_L{currIdx}));
        
        %add extra edge
        edges(edgeAddIdx).src = nodes{currIdx};
        edges(edgeAddIdx).len = 1;
        edges(edgeAddIdx).dst = nodes{nodeAddIdx};
        edges(k).len = edges(k).len - 1;
        PUL{edgeAddIdx} = PUL{k};
        
        %advance node to newly created node
        currIdx = nodeAddIdx;
        
        nodeAddIdx = nodeAddIdx + 1;
        edgeAddIdx = edgeAddIdx + 1;
    end
    
    %the original edge can now be moved to the end of the line of
    %additional nodes created: replace src of the original edge with the
    %lastly created node
    edges(k).src = nodes{currIdx};
end

end