function [edge idx] = findEdge(leaf, parent, edges)
%FINDEDGE will search for an edge connecting 'leaf' and 'parent' nodes
%
% SYNOPSIS [edge idx] = findEdge(leaf, parent, edges)
%
% INPUT leaf: id of the child node
%       parent: id of the parent of the leaf node
%       edges: struct array of edges
%
% OUTPUT edge: the element of the 'edges'-array that has leaf and parent as
%               source and destination (or the other way round).
%        idx: id of the edge in the 'edges' struct array
%
% it is assumed that edges is an array of structs, and that the structs
% have the fields 'srcIdx' and 'dstIdx', meaning the source and destination
% indices of the edge.
%
% The algorithm will fail if there is more than one edge that connects
% 'leaf' and 'parent', or if there is no edge that connects those two
% nodes.
%

%sanity checks
if (~isfield(edges, 'srcIdx') || ~isfield(edges, 'dstIdx'))
    error('"edges" must have fields "srcIdx" and "dstIdx"');
end

%get the ID of the edge
edgeIdx = ( ([edges.srcIdx] == leaf) & ([edges.dstIdx] == parent) | ...
            ([edges.dstIdx] == leaf) & ([edges.srcIdx] == parent) );

%check if we found exactly one edge
if (0 == sum(edgeIdx))
    disp('edges src: ');
    disp({edges.src});
    disp('edges dst: ');
    disp({edges.dst});
    error(['Could not find an edge between ' num2str(leaf) ' and ' ...
        num2str(parent)]);
elseif (sum(edgeIdx) > 1)
    disp(['more than one edge found from node ' num2str(leaf) ...
        ' to node ' num2str(parent) '.']);
    disp('ids of the edges that got a match: ');
    disp(find(edgeIdx));
    error('expected only one edge to exist between two entities');
else
    %everythings alright
    edge = edges(edgeIdx);
    idx = find(edgeIdx);
end
