function Y_E = node2EdgeLoad(Y_N, conn)
%NODE2EDGELOAD computes node admittance for a subset of ports
%
% SYNOPSIS Y_E = node2EdgeLoad(Y_N, conn)
%
% INPUT Y_N     : Load admittance matrix at the node
%       conn    : connection array
%
% OUTPUT Y_E: load admittance matrix as seen at connected ports
%
% If we have a load network, but only connect to a subset of the ports of
% the load network, the load admittance matrix needs to be rebuild. Take
% for example a load network with two ports, the first port is connected to
% ground via 50 ohm resistance, and the second port is connected to the
% first port via 50 ohm resistance. If we connect to all ports, the load
% admittance matirx therefore is Y_L = [1/25, -1/50; -1/50 1/50]. If we
% connect to the second port only however, the load admittance matrix
% becomes Y_L = 1/100.

nE = size(Y_N, 1); %number of ports at the node
nF = size(Y_N, 3); %number of frequencies

Y_E = zeros(length(conn), length(conn), nF);

c = conn; %set of connected ports
nc = setdiff(1:nE, c); %set of not connected ports

%for more information about whats happening below, see the thesis. The
%basic idea is that all currents at not connected ports is zero.
for k = 1:nF
    %zr denotes the rows that are zero, i.e ports that are not connected
    %inside the load network. we need to exclude those because otherwise
    %our matrix system would not be solvable
    zr = find(all(0 == Y_N(:,:,k), 2));
    ncnz = setdiff(nc, zr);

    gamma = Y_N(ncnz, nc, k) \ (-Y_N(ncnz, c, k));

    Y_E(:,:,k) = Y_N(c,c, k) + Y_N(c, nc, k) * gamma;
end