function treeplotWText(tree, nodePos) 
%TREEPLOTWTEXT plot a tree with text at the nodes
%
% SYNOPSIS treeplotWText(tree, nodePos)
%
% INPUT tree
%           .parent: matlab-style tree array
%           .descr: description of node
%       nodePos: optional position of nodes. If omitted, positions will be
%       computed using matlabs treelayout routine
%
% OUTPUT --
%
% plots a graph of the tree with tree.descr as annotations to the nodes
% y = tree.parent(x) means that node with id y is parent of node with id x

numNodes = length(tree);

%sanity checks
if (~isstruct(tree))
    error('expected first argument to be a struct');
end
if (~isfield(tree, 'parent'))
    error('expected first argument to have field "parent"');
end
if (~isfield(tree, 'descr'))
    error('expected first argument to have field "descr"');
end

if (~exist('nodePos', 'var'))
    [xc yc] = treelayout([tree.parent]);
    nodePos = [xc' yc'];
end

if (size(nodePos, 1) ~= numNodes)
    error('nodePos must contain numNodes rows');
end
if (size(nodePos, 2) ~= 2)
    error('nodePos must contain 2 columns, x and y');
end

figure;
hold on;
axis off;

%plot the tree
for currNode = 1:numNodes
   
    %plot the current node
    x = nodePos(currNode, 1);
    y = nodePos(currNode, 2);
    plot(x, y, 'o');
    text(x, y, tree(currNode).descr);
    
    %plot the edge to the parent
    parent = tree(currNode).parent;
    if (0 == parent)
        continue;
    end
    px = nodePos(parent, 1);
    py = nodePos(parent, 2);
%     tx = (px + x)/2;
%     ty = (py + y)/2;
    line([x px], [y py]);
    
end

end