function C = compCap(CGen, refC)
%COMPCAP computes the capacitance matrix using the generalized matrix
%
% SYNOPSIS C = compCap(CGen, refC)
% 
% INPUT CGen: generalized capacitance matrix
% 		refC: reference conductor
%
% OUTPUT C: capacitance matrix
%
% Computes the capacitance matrix for a given reference conductor
% using the generalized capacitance matrix.

N = size(CGen, 1);

if (N ~= size(CGen,2))
    error('compCap: CGen must be square');
end

C = zeros(N-1);

sumCGen = sum(sum(CGen));
rInd = 0;
for i= 1:N
    if (i ~= refC)
        rInd = rInd + 1;
        cInd = 0;
        for j = 1:N
            if (j ~= refC)
                cInd = cInd + 1;
                C(rInd,cInd) = CGen(i,j) - sum(CGen(i,:))*sum(CGen(:,j))/sumCGen;
            end
        end
    end
end

end
