function psi = getPsi(m,n, preCompPsi)
%GETPSI returns psi at coordinates m,n
%
% SYNOPSIS psi = getPsi(m,n, preCompPsi)
%
% INPUT: m,n: coordinate point
%		 preCompPsi: upper triangular matrix with precomputed values for psi
%
% OUTPUT: psi, the potential difference
%
%For the computation of psi, either the precomputed values given in preCompPsi
%are used, if they exist for the given (m,n) or an approximate formula for 
% r = sqrt(m^2+n^2) -> inf is used.
%
%Note: the used formula for r-> inf should not be used for m,n < 6, 
%depending on the desired accuracy
%
[imax, jmax] = size(preCompPsi);

i = abs(m)+1;
j = abs(n)+1;

%formula for r = sqrt(m^2+n^2) -> inf
if ( (i > imax) || (j > jmax) )
    psi = 1 - (1/(4*pi)) * ( log(8*(m*m + n*n)) + 2*0.57721566490153286060 );
    return;
end

%psi(m,n) = psi(n,m) = psi(m,-n)
if (i > j)
    t = i;
    i = j;
    j = t;
end

psi = preCompPsi(i,j);

end
