function [S1rows, S1cols] = getS1Coord(M,N)
%GETS1COORD returns (x,y) coordinates for a border two off the maximum grid size
%
% SYNOPSIS [S1rows S1cols] = getS1Coord(M,N)
%
% INPUT: M,N: grid size
%
% OUTPUT: S1rows: row number of the inner border points. First point is located
%			at the top left corner
%		  S1cols: column number of the inner border points
%
% Figure containing the borders. 1s indicate that point in the mesh belongs
% to border 1 (inner border), 2s indicate it belongs to border 2 (outer border).
% #s indicate that the point isn't allocated to any border.
%
% Image for k = 2:
% 1234...........N
% 2222222222222222  1
% 2##############2  2
% 2##############2  3
% 2##1111111111##2  4
% 2##1########1##2  .
% 2##1########1##2  .
% 2##1111111111##2  .
% 2##############2  .
% 2##############2  .
% 2222222222222222  M
%
%
% %
% 	S1rows = [ 2*ones(1, N-2) 3:(M-2) (M-1)*ones(1,N-2) (M-2):-1:3  ];
% 	S1cols = [ 2:(N-1) (N-1)*ones(1, M-4) (N-1):-1:2 2*ones(1, M-4) ];

%how many pixels shall be between S1 and S2?
k = 2;

if (M < 3*k) || (N < 3*k)
    error('k too large');
end

S1rows = [ (2+k)*ones(1, N-(1+k)*2)    (3+k):+1:(M-(2+k)) ...
           (M-(1+k))*ones(1,N-(1+k)*2) (M-(2+k)):-1:(3+k) ];

S1cols = [ (2+k):+1:(N-(1+k)) (N-(1+k))*ones(1, M-(2+k)*2) ...
           (N-(1+k)):-1:(2+k) (2+k)*ones(1, M-(2+k)*2) ];
    
end
