function [S2rows, S2cols] = getS2Coord(M,N)
%GETS2COORD returns (x,y) coordinates for a border of the grid without corners
%
% SYNOPSIS [S2rows S2cols] = getS2Coord(M,N)
%
% INPUT: M,N: grid size
%
% OUTPUT: S2rows: row number of the outer border points. First point is located
%			at the most left point of the top edge
%		  S2cols: column number of the outer border points
%
% Figure containing the borders. 1s indicate that point in the mesh belongs
% to border 1 (inner border), 2s indicate it belongs to border 2 (outer border).
% #s indicate that the point isn't allocated to any border.
%
% 1234...........N
% 2222222222222222  1
% 2##############2  2
% 2##############2  3
% 2##1111111111##2  4
% 2##1########1##2  .
% 2##1########1##2  .
% 2##1111111111##2  .
% 2##############2  .
% 2##############2  .
% 2222222222222222  M

S2rows = [ ones(1, N) 2:(M-1) M*ones(1, N) (M-1):-1:2 ];
S2cols = [ 1:N N*ones(1, M-2) N:-1:1 ones(1, M-2) ];

end
