function b = isValidQ(Q, thresh)

if (~exist('thresh', 'var'))
    thresh = 1e-12;
end

b = true;

[R C] = size(Q);

if (0 ~= mod(R,4))
    error('Only matrices that have rowlength multiple of four supported');
end

if (0 ~= mod(C,4))
    error('Only matrices that have a multiple of four as number of columns are supported');
end

sMR = R/4; %SubMatrixRows: rows in one submatrx
sMC = C/4; %SubMatrixColumns

Q1 = Q(1:sMR,       1:  sMC);
Q2 = Q(1:sMR,   sMC+1:2*sMC);
Q3 = Q(1:sMR, 2*sMC+1:3*sMC);
Q4 = Q(1:sMR, 3*sMC+1:4*sMC);

Q1R = revMat(Q1);
Q2R = revMat(Q2);
Q3R = revMat(Q3);
Q4R = revMat(Q4);

if (max(max(Q(sMR+1:2*sMR, 1:sMC) - Q2R)) > thresh)
    disp('Second row, first column mismatch');
    b = false;
end

if (max(max(Q(sMR+1:2*sMR, sMC+1:2*sMC) - Q1R)) > thresh)
    disp('Second row, second column mismatch');
    b = false;
end

if (max(max(Q(sMR+1:2*sMR, 2*sMC+1:3*sMC) - Q4R)) > thresh)
    disp('Second row, third column mismatch');
    b = false;
end

if (max(max(Q(sMR+1:2*sMR, 3*sMC+1:4*sMC) - Q3R)) > thresh)
    disp('Second row, fourth column mismatch');
    b = false;
end

if (max(max(Q(2*sMR+1:3*sMR, 1:sMC) -Q3)) > thresh)
    disp('Third row, first column mismatch');
    b = false;
end

if (max(max(Q(2*sMR+1:3*sMR, sMC+1:2*sMC) - Q4)) > thresh)
    disp('Third row, second column mismatch');
    b = false;
end

if (max(max(Q(2*sMR+1:3*sMR, 2*sMC+1:3*sMC) - Q1)) > thresh)
    disp('Third row, third column mismatch');
    b = false;
end

if (max(max(Q(2*sMR+1:3*sMR, 3*sMC+1:4*sMC) - Q2)) > thresh)
    disp('Third row, fourth column mismatch');
    b = false;
end


if (max(max(Q(3*sMR+1:4*sMR, 1:sMC) -Q4R)) > thresh)
    disp('Fourth row, first column mismatch');
    b = false;
end

if (max(max(Q(3*sMR+1:4*sMR, sMC+1:2*sMC) - Q3R)) > thresh)
    disp('Fourth row, second column mismatch');
    b = false;
end

if (max(max(Q(3*sMR+1:4*sMR, 2*sMC+1:3*sMC) - Q2R)) > thresh)
    disp('Fourth row, third column mismatch');
    b = false;
end

if (max(max(Q(3*sMR+1:4*sMR, 3*sMC+1:4*sMC) - Q1R)) > thresh)
    disp('Fourth row, fourth column mismatch');
    b = false;
end

end