addpath('input'); %genMat(Circ) in there
addpath('pul'); %mtlPUL

%%%%%%%%%
%Compute PUL parameters for ribbon cables
%%%%%%%%%

%frequencies at which the PUL parameters should be computed
f = 1e5:1e5:80e6;

%maximum number of nodes
nodesMax = 20000;

%input files basename
ribbon = 'input/2vert_ribbon';

%generate input matrices for mtlPUL
[cIm E_R refC] = genMat(nodesMax, ribbon);

%execute the FDM algorithm to determine the PUL parameters
[C L G1] = mtlPUL(cIm, E_R, refC);
%G1 is G for omega = 1.

%compute linearly frequency dependent G. See thesis for more details.
G = zeros([size(G1) length(f)]);
for k = 1:length(f)
    G(:,:,k) = G1 * 2*pi*f(k);
end

%notice how the genMat-function and the genResMat-function have different
%input files, as they need different parameters (all geometric properties
%of the setup are given by the image)
R = genResMat(f, 'input/2vert_ribbon_R.mat');

save('output/2vert_ribbon.mat', 'R', 'C', 'L', 'G', 'ribbon');
