addpath('input'); %genMat(Circ) in there
addpath('pul'); %mtlPUL

%%%%%%%%%
%Compute PUL parameters for symmetric cable
%%%%%%%%%

%frequencies at which the PUL parameters should be computed
f = 1e5:1e5:80e6;

%nodes per unit of distance to be used when discretising
nodesPerUnit = 18000;
%input variables
symm = load('input/symm.mat');
%generate input matrices for mtlPUL
[cIm E_R refC] = genMatCirc(nodesPerUnit, symm);

%execute the FDM algorithm to determine the PUL parameters
[C L G1] = mtlPUL(cIm, E_R, refC);
%G1 is G for omega = 1.

%compute linearly frequency dependent G. See thesis for more details.
G = zeros([size(G1) length(f)]);
for k = 1:length(f)
    G(:,:,k) = G1 * 2*pi*f(k);
end

%R uses the same input as genMatCirc
R = genResMat(f, symm);

save('output/symm.mat', 'R', 'C', 'L', 'G', 'symm');